translate.misc.xmlwrapper.XMLWrapper

Package translate :: Package misc :: Module xmlwrapper :: Class XMLWrapper |
[hide private]
[frames] | no frames]

# Class XMLWrapper

source code

simple wrapper for xml objects

Instance Methods | [hide private]
__init__(self, obj) construct object from the elementtree item | source code
getchild(self, searchtag, tagclass=None) get a child with the given tag name | source code
getchildren(self, searchtag, tagclass=None, excludetags=`[``]`) get all children with the given tag name | source code
gettext(self, searchtag) get some contained text | source code
getxml(self, encoding=None) | source code
getplaintext(self, excludetags=`[``]`) | source code
getvalues(self, searchtag) get some contained values... | source code
__repr__(self) return a representation of the object | source code
getattr(self, attrname) gets an attribute of the tag | source code
write(self, file, encoding=`'``UTF-8``'`) writes the object as XML to a file... | source code